[nongnu] elpa/slime 5ced74ab35: find-definition: fix parsing defmethod with an empty lambda-list.

2024-05-15 Thread ELPA Syncer
branch: elpa/slime
commit 5ced74ab35d91f6be7d8fa10e1098aaae6b749e3
Author: Stas Boukarev 
Commit: Stas Boukarev 

find-definition: fix parsing defmethod with an empty lambda-list.
---
 swank.lisp | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/swank.lisp b/swank.lisp
index ab742fda8a..522c90cfb0 100644
--- a/swank.lisp
+++ b/swank.lisp
@@ -3154,12 +3154,12 @@ DSPEC is a string and LOCATION a source location. NAME 
is a string."
  (qualifiers)
  (specializers))
  (loop for x = (pop sexp)
-   when (consp x)
+   when (listp x)
do (setf specializers x)
   (return)
else do (push x qualifiers)
while sexp)
- (find-method (fdefinition gf) qualifiers 
+ (find-method (fdefinition gf) qualifiers
   (mapcar (lambda (spec)
 (etypecase spec
   (symbol (find-class spec))



[elpa] externals/org-modern 750fd57ec1: Simplify faces

2024-05-15 Thread ELPA Syncer
branch: externals/org-modern
commit 750fd57ec119a7044bbc3ee5244d48bacacc592d
Author: Daniel Mendler 
Commit: Daniel Mendler 

Simplify faces
---
 org-modern.el | 9 -
 1 file changed, 4 insertions(+), 5 deletions(-)

diff --git a/org-modern.el b/org-modern.el
index 1dc480cd13..cd8c11daaa 100644
--- a/org-modern.el
+++ b/org-modern.el
@@ -290,14 +290,13 @@ the font.")
 
 (defface org-modern-progress-complete
   'background light))
- :background "gray35" :foreground "white" :distant-foreground "black")
-(t :background "gray75" :foreground "black" :distant-foreground "white"))
+ :background "gray35" :foreground "white")
+(t :background "gray75" :foreground "black"))
   "Face used for completed section of progress bars (colors only).")
 
 (defface org-modern-progress-incomplete
-  '((default :background "gray50")
-(((background light)) :foreground "gray95" :distant-foreground "gray5")
-(t :foreground "gray5" :distant-foreground "gray95"))
+  'background light)) :background "gray90" :foreground "black")
+(t :background "gray20" :foreground "white"))
   "Face used for incomplete section of progress bars (colors only).")
 
 (defface org-modern-tag



[elpa] externals/llm updated (46347e4919 -> efe218ac13)

2024-05-15 Thread ELPA Syncer
elpasync pushed a change to branch externals/llm.

  from  46347e4919 Fix swapped words in llm-vertex copyright notice
   new  2c1e34ab18 Add upcoming minor version to NEWS
   new  25a4436d15 Fix Vertex response handling bug
   new  efe218ac13 Set version to 0.14.2


Summary of changes:
 NEWS.org  | 5 -
 llm-vertex.el | 3 ++-
 llm.el| 2 +-
 3 files changed, 7 insertions(+), 3 deletions(-)



[elpa] externals/llm efe218ac13 3/3: Set version to 0.14.2

2024-05-15 Thread ELPA Syncer
branch: externals/llm
commit efe218ac13144ea8f062912da12ac8599162e705
Author: Andrew Hyatt 
Commit: Andrew Hyatt 

Set version to 0.14.2
---
 llm.el | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/llm.el b/llm.el
index 75630b6529..14b5cfd715 100644
--- a/llm.el
+++ b/llm.el
@@ -5,7 +5,7 @@
 ;; Author: Andrew Hyatt 
 ;; Homepage: https://github.com/ahyatt/llm
 ;; Package-Requires: ((emacs "28.1"))
-;; Package-Version: 0.14.1
+;; Package-Version: 0.14.2
 ;; SPDX-License-Identifier: GPL-3.0-or-later
 ;;
 ;; This program is free software; you can redistribute it and/or



[elpa] externals/llm 2c1e34ab18 1/3: Add upcoming minor version to NEWS

2024-05-15 Thread ELPA Syncer
branch: externals/llm
commit 2c1e34ab184e4132b1238db9d53d74f51b632a74
Author: Andrew Hyatt 
Commit: Andrew Hyatt 

Add upcoming minor version to NEWS
---
 NEWS.org | 4 +++-
 1 file changed, 3 insertions(+), 1 deletion(-)

diff --git a/NEWS.org b/NEWS.org
index f24fc540ce..c5ad45ade4 100644
--- a/NEWS.org
+++ b/NEWS.org
@@ -1,4 +1,6 @@
-* Veresion 0.14.1
+* Version 0.14.2
+- Fix mangled copyright line (needed to get ELPA version unstuck).
+* Version 0.14.1
 - Fix various issues with the 0.14 release
 * Version 0.14
 - Introduce new way of creating prompts: llm-make-chat-prompt, deprecating the 
older ways.



[elpa] externals/llm 25a4436d15 2/3: Fix Vertex response handling bug

2024-05-15 Thread ELPA Syncer
branch: externals/llm
commit 25a4436d152f590e6b718e9b6b768daf76e7d169
Author: Andrew Hyatt 
Commit: Andrew Hyatt 

Fix Vertex response handling bug
---
 NEWS.org  | 1 +
 llm-vertex.el | 3 ++-
 2 files changed, 3 insertions(+), 1 deletion(-)

diff --git a/NEWS.org b/NEWS.org
index c5ad45ade4..fc1fc72faa 100644
--- a/NEWS.org
+++ b/NEWS.org
@@ -1,5 +1,6 @@
 * Version 0.14.2
 - Fix mangled copyright line (needed to get ELPA version unstuck).
+- Fix Vertex response handling bug.
 * Version 0.14.1
 - Fix various issues with the 0.14 release
 * Version 0.14
diff --git a/llm-vertex.el b/llm-vertex.el
index b52a6f3339..745609f2a1 100644
--- a/llm-vertex.el
+++ b/llm-vertex.el
@@ -140,7 +140,8 @@ KEY-GENTIME keeps track of when the key was generated, 
because the key must be r
 (cl-defmethod llm-provider-chat-extract-result ((provider llm-google) response)
   (pcase (type-of response)
 ('vector (when (> (length response) 0)
-   (let ((parts (mapcar #'llm-provider-chat-extract-result 
provider response)))
+   (let ((parts (mapcar (lambda (part) 
(llm-provider-chat-extract-result provider part))
+response)))
  (if (stringp (car parts))
  (mapconcat #'identity parts "")
(car parts)



[nongnu] elpa/gruvbox-theme 3388a96d8e: Improve contrast of diff-refine for dark-* and light-* themes

2024-05-15 Thread ELPA Syncer
branch: elpa/gruvbox-theme
commit 3388a96d8e59c120bc243c1f90c614237f6ac3b5
Author: Ruiyang Wu 
Commit: Jason Milkins 

Improve contrast of diff-refine for dark-* and light-* themes
---
 gruvbox.el | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/gruvbox.el b/gruvbox.el
index fe1a080897..24545650b8 100644
--- a/gruvbox.el
+++ b/gruvbox.el
@@ -207,9 +207,9 @@ Should contain 2 %s constructs to allow for theme name and 
directory/prefix")
  (diff-hunk-header  (:background gruvbox-dark2))
  (diff-context  (:background gruvbox-dark1 
:foreground gruvbox-light1))
  (diff-added(:background 'unspecified  
:foreground gruvbox-neutral_green))
- (diff-refine-added (:background 
gruvbox-faded_green  :foreground gruvbox-bright_green :bold t))
+ (diff-refine-added (:background 
gruvbox-faded_green  :foreground gruvbox-light1))
  (diff-removed  (:background 'unspecified  
:foreground gruvbox-neutral_red))
- (diff-refine-removed   (:background gruvbox-faded_red 
 :foreground gruvbox-bright_red :bold t))
+ (diff-refine-removed   (:background gruvbox-faded_red 
 :foreground gruvbox-light1))
  (diff-indicator-changed(:inherit 'diff-changed))
  (diff-indicator-added  (:inherit 'diff-added))
  (diff-indicator-removed(:inherit 'diff-removed))



[elpa] externals/auctex 7b9efc2e17 08/13: ; * style/amsrefs.el ("amsrefs"): Add the "biblist*" environment.

2024-05-15 Thread ELPA Syncer
branch: externals/auctex
commit 7b9efc2e17c25bdb7e928e9eb865d2c09f3326b8
Author: Arash Esbati 
Commit: Arash Esbati 

; * style/amsrefs.el ("amsrefs"): Add the "biblist*" environment.
---
 style/amsrefs.el | 3 ++-
 1 file changed, 2 insertions(+), 1 deletion(-)

diff --git a/style/amsrefs.el b/style/amsrefs.el
index babfebb12b..0452b894ad 100644
--- a/style/amsrefs.el
+++ b/style/amsrefs.el
@@ -121,7 +121,8 @@
;; 3 The biblist and biblist* environments
(LaTeX-add-environments
 '("bibdiv")
-'("biblist" LaTeX-env-amsrefs-biblist))
+'("biblist" LaTeX-env-amsrefs-biblist)
+'("biblist*" LaTeX-env-amsrefs-biblist))
 
(TeX-add-symbols
 ;; 5 More about the \bib command



[elpa] externals/auctex bf7ceef14f 06/13: ; * NEWS.org: Update the file.

2024-05-15 Thread ELPA Syncer
branch: externals/auctex
commit bf7ceef14fbe8e9c3deb8d285de33147977ef0ed
Author: Arash Esbati 
Commit: Arash Esbati 

; * NEWS.org: Update the file.
---
 NEWS.org | 137 +++
 1 file changed, 137 insertions(+)

diff --git a/NEWS.org b/NEWS.org
index f0649d6f59..09e98daa59 100644
--- a/NEWS.org
+++ b/NEWS.org
@@ -67,3 +67,140 @@
 
 - Revert usage of ~:local~ tag inside ~defcustom~.  This tag isn't
   handled correctly in Emacs 27.1 and breaks AUCTeX.
+
+* [14.0.3] - 2024-02-20
+
+** Fixed
+
+- Cater for former mode name in customized ~TeX-command-list~.
+- Fix and enhance pseudo-parent mode facility.
+
+* [14.0.2] - 2024-02-09
+
+** Fixed
+
+- Fix ELPA releases.
+
+* [14.0.1] - 2024-02-08
+
+** Added
+
+- AUCTeX changes major mode names.  Its primary purpose is to avoid
+  conflicts with Emacs built-in TeX major modes.  It also improves
+  consistency of the source code.
+  - The overview of the former names and new names are:
+| Former name   | New name  |
+|---+---|
+| ~plain-tex-mode~  | ~plain-TeX-mode~  |
+| ~latex-mode~  | ~LaTeX-mode~  |
+| ~doctex-mode~ | ~docTeX-mode~ |
+| ~texinfo-mode~| ~Texinfo-mode~|
+| ~ams-tex-mode~| ~AmSTeX-mode~ |
+| ~japanese-plain-tex-mode~ | ~japanese-plain-TeX-mode~ |
+| ~japanese-latex-mode~ | ~japanese-LaTeX-mode~ |
+
+The undocumented modes ~context-en-mode~ and ~context-nl-mode~ were
+deleted.
+  - We paid much attention to the compatibility and expect that almost
+no particular treatment on the user side is needed.  For example,
+the names of the keymaps and mode hooks remain unchanged, and the
+=mode:= tag in the file local variables in the existing files works
+with old mode names.  See below for more details
+  - If your Emacs is 29 or newer and you use =desktop.el= to save and
+restore Emacs sessions, be careful before you update AUCTeX; You
+should attempt to update only after
+1. you kill all buffer under former AUCTeX modes which have
+   overlapped name with Emacs built-in TeX modes, and
+2. you terminate the current Emacs session.
+The modes with such overlapped name are ~plain-tex-mode~,
+~latex-mode~, ~doctex-mode~ and ~texinfo-mode~.  (The above
+prescription ensures no buffer of such modes is recorded in the
+desktop file.  Otherwise those buffers would be restored in the
+built-in modes, not AUCTeX modes, after the update of AUCTeX.)
+  - New mode names are chosen to match the existing variables, so most
+user customizations as well as the third party libraries would
+continue to work without modification.  For example, names of
+keymaps and hooks don't change as stated above.
+(~AmS-TeX-mode-hook~ is renamed to ~AmSTeX-mode-hook~, but
+compatibility alias is provided.)
+  - Now ~TeX-add-local-master~ adds entry of new mode names such as
+#+begin_example
+  %%% Local Variables:
+  %%% mode: LaTeX  <-- not `latex'
+  %%% End:
+#+end_example
+  - The compatibility with the former mode names with respect to
+invoking the major mode are retained.
+1. Former modes which overlap with built-in modes, namely
+   ~plain-tex-mode~, ~latex-mode~, ~doctex-mode~, ~texinfo-mode~ and
+   ~tex-mode~ are handled by redirections; the same override advices
+   as before are continued to used for Emacs<29 while
+   ~major-mode-remap-alist~ is used for Emacs 29 and later.
+   (Therefore, if there are user codes which call ~latex-mode~
+   directly, built-in ~latex-mode~ runs instead of AUCTeX
+   ~LaTeX-mode~ in Emacs 29 and later.)
+
+   These redirections still honor your customization to ~TeX-modes~
+   option.  Thus you are served by built-in ~plain-tex-mode~ and
+   AUCTeX ~LaTeX-mode~ if you exclude ~plain-tex-mode~ from
+   ~TeX-modes~.
+2. Other former names, e.g. ~context-mode~ and
+   ~japanese-latex-mode~, are handled by aliases such as
+   #+begin_src emacs-lisp
+ (defalias 'context-mode #'ConTeXt-mode)
+   #+end_src
+  - New modes recognize directory local variables prepaired for the
+former mode name.  For example, directory local variables for
+~latex-mode~ are valid in ~LaTeX-mode~ as well.  So you don~t have
+to rewrite every former mode name to the new one in
+=.dir-locals.el=.
+  - Your abbrevs are preserved.  For example, ~latex-mode-abbrev-table~,
+if exists, is automatically included as a parent of
+~LaTeX-mode-abbrev-table~.
+  - Now all major modes are defined by ~define-derived-mode~, so
+standard inheritance of keymaps, syntax tables etc. takes place.
+The inheritance relations are:
+#+begin_example
+  text-mode  --+-- TeX-mode
+ 

[elpa] externals/auctex 774974185a 07/13: Fix compilation on Emacs 27

2024-05-15 Thread ELPA Syncer
branch: externals/auctex
commit 774974185a1a49db4ff0d48121c33b77e0546a04
Author: Ikumi Keita 
Commit: Ikumi Keita 

Fix compilation on Emacs 27

* tex.el (require): Require subr-x for `if-let' introduced in
`TeX-master-output-file'.
---
 tex.el | 3 ++-
 1 file changed, 2 insertions(+), 1 deletion(-)

diff --git a/tex.el b/tex.el
index e13c02ce17..749037b5eb 100644
--- a/tex.el
+++ b/tex.el
@@ -34,7 +34,8 @@
 (require 'custom)
 (require 'tex-site)
 (eval-when-compile
-  (require 'cl-lib))
+  (require 'cl-lib)
+  (require 'subr-x))
 (require 'texmathp)
 ;; seq.el is preloaded in Emacs 29, so the next form can be removed
 ;; once 29 is the minimum required Emacs version



[elpa] externals/auctex 600b92446f 09/13: ; * NEWS.org: Fix last change.

2024-05-15 Thread ELPA Syncer
branch: externals/auctex
commit 600b92446fd767a7888ca7924b2c34252074d7ff
Author: Arash Esbati 
Commit: Arash Esbati 

; * NEWS.org: Fix last change.
---
 NEWS.org | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/NEWS.org b/NEWS.org
index 09e98daa59..7a21f22730 100644
--- a/NEWS.org
+++ b/NEWS.org
@@ -151,7 +151,7 @@
#+end_src
   - New modes recognize directory local variables prepaired for the
 former mode name.  For example, directory local variables for
-~latex-mode~ are valid in ~LaTeX-mode~ as well.  So you don~t have
+~latex-mode~ are valid in ~LaTeX-mode~ as well.  So you don't have
 to rewrite every former mode name to the new one in
 =.dir-locals.el=.
   - Your abbrevs are preserved.  For example, ~latex-mode-abbrev-table~,
@@ -190,7 +190,7 @@
 
 However, ~Texinfo-mode~ is exceptional in the following two aspects:
 1. It doesn't inherit ~text-mode-syntax-table~ because it simply
-   uses built-in mode~s ~texinfo-mode-syntax-table~, which is
+   uses built-in mode's ~texinfo-mode-syntax-table~, which is
independent of ~text-mode-syntax-table~.  This situation is the
same with the former AUCTeX Texinfo mode.
 2. ~Texinfo-mode-map~ has ~TeX-mode-map~ as its direct parent.  This



[elpa] externals/auctex updated (5a64a805e5 -> 543d92aa89)

2024-05-15 Thread ELPA Syncer
elpasync pushed a change to branch externals/auctex.

  from  5a64a805e5 Merge remote-tracking branch 'origin/master'
   new  1d66dd1f6f Enable lexical-binding in auto-generated styles
   new  5f039df961 ; * NEWS.org: Update the file.
   new  cba5820cf8 Allow compilation messages to be suppressed
   new  59ddea9f13 Correct variable name
   new  61f8825cfd Add new style/amsrefs.el
   new  bf7ceef14f ; * NEWS.org: Update the file.
   new  774974185a Fix compilation on Emacs 27
   new  7b9efc2e17 ; * style/amsrefs.el ("amsrefs"): Add the "biblist*" 
environment.
   new  600b92446f ; * NEWS.org: Fix last change.
   new  a7f80ab858 Replace `TeX-arg-eval' in style/moodle.el
   new  970787f92d Improve paragraph commands management for ConTeXt mode 
(bug#70811)
   new  e30189d92a ; * NEWS.org: Update for 14.0.5 ELPA release.
   new  543d92aa89 Merge remote-tracking branch 'origin/master'


Summary of changes:
 NEWS.org | 153 +++-
 context.el   |  63 +
 latex.el |   2 +-
 style/amsrefs.el | 234 +
 style/moodle.el  | 263 ---
 tex.el   |  14 ++-
 6 files changed, 576 insertions(+), 153 deletions(-)
 create mode 100644 style/amsrefs.el



[elpa] externals/auctex a7f80ab858 10/13: Replace `TeX-arg-eval' in style/moodle.el

2024-05-15 Thread ELPA Syncer
branch: externals/auctex
commit a7f80ab858775cd00f76637d70504941535898ae
Author: Arash Esbati 
Commit: Arash Esbati 

Replace `TeX-arg-eval' in style/moodle.el

* style/moodle.el (LaTeX-moodle-question-env-with-args): Delete
function.
(LaTeX-moodle-answer-key-val-options): New variable.
(LaTeX-moodle-key-val-options): Use it.
(LaTeX-moodle-question-env-with-args): Delete function.
(LaTeX-moodle-item-argument): Expand function to recognize
different environments.
(LaTeX-moodle-query-question-text): New function.
("moodle"): Use new functions and replace `TeX-arg-eval'.
Don't expose lambda's to the compiler.
(LaTeX-moodle-package-options): Update package options.
---
 style/moodle.el | 263 +---
 1 file changed, 134 insertions(+), 129 deletions(-)

diff --git a/style/moodle.el b/style/moodle.el
index ac5f2866db..cf629078f5 100644
--- a/style/moodle.el
+++ b/style/moodle.el
@@ -1,6 +1,6 @@
 ;;; moodle.el --- AUCTeX style for `moodle.sty' (v0.5)  -*- lexical-binding: 
t; -*-
 
-;; Copyright (C) 2017, 2018, 2020 Free Software Foundation, Inc.
+;; Copyright (C) 2017--2024 Free Software Foundation, Inc.
 
 ;; Author: Arash Esbati 
 ;; Maintainer: auctex-de...@gnu.org
@@ -43,158 +43,161 @@
   "font-latex"
   (keywords class))
 
+(defvar LaTeX-moodle-answer-key-val-options
+  '(("fraction")
+("fractiontol")
+("feedback")))
+
 (defvar LaTeX-moodle-key-val-options
-  '(("points")
-("default grade")
-("penalty")
-("fraction")
-("feedback"))
+  (append '(("points")
+("default grade")
+("penalty")
+("tags"))
+  LaTeX-moodle-answer-key-val-options)
   "Key=value options for moodle macros and environments.")
 
-(defun LaTeX-moodle-question-env-with-args (env)
-  "Insert ENV provided by moodle.sty incl. arguments and first \\item."
-  (LaTeX-insert-environment
-   env
-   (let ((opts (TeX-read-key-val
-t
-(cond (;; 3.3.1 Multiple Choice
-   (string= env "multi")
-   (append '(("shuffle"   ("true" "false"))
- ("numbering" ("alph" "Alph" "arabic"
-   "roman" "Roman" "none"))
- ("single"("true" "false"))
- ("multiple"  ("true" "false")))
-   (when (string= "cloze" 
(LaTeX-current-environment))
- '(("vertical" ("true" "false"))
-   ("horizonal" ("true" "false"
-   LaTeX-moodle-key-val-options))
-  ;; 3.3.3 Short Answer
-  ((string= env "shortanswer")
-   (append '(("case sensitive" ("true" "false"))
- ("usecase"("true" "false")))
-   (when (string= "cloze" 
(LaTeX-current-environment))
- '(("vertical" ("true" "false"))
-   ("horizonal" ("true" "false"
-   LaTeX-moodle-key-val-options))
-  ;; 3.3.4 Essay Questions
-  ((string= env "essay")
-   (append '(("response required" ("true" "false"))
- ("response format"   ("html" "file"
-   "html+file"
-   "text" "monospaced"))
- ("response field lines")
- ("attachments allowed"  ("0" "1" "2" "3"
-  "unlimited"))
- ("attachments required" ("0" "1" "2" "3"))
- ("response template"))
-   (when (string= "cloze" 
(LaTeX-current-environment))
- '(("vertical" ("true" "false"))
-   ("horizonal" ("true" "false"
-   LaTeX-moodle-key-val-options))
-  ;; 3.4 Matching Questions
-  ((string= env "matching")
-   (append '(("shuffle"   ("true" "false"))
- ("drag and drop" ("true" "false"))
- ("dd"("true" "false")))
-   LaTeX-moodle-key-val-options))
-  (t (append
-  (when (string= "cloze" (LaTeX-current-environment))
-'(("vertical" ("true" "false"))
-  ("horizonal" ("true" "false"
-  LaTeX-moodle-key-val-options)
- (qname (unless (string= "cloze" (LaTe

[elpa] externals/auctex 970787f92d 11/13: Improve paragraph commands management for ConTeXt mode (bug#70811)

2024-05-15 Thread ELPA Syncer
branch: externals/auctex
commit 970787f92d21447296c474bee954ac1ac3e0b8de
Author: Ikumi Keita 
Commit: Ikumi Keita 

Improve paragraph commands management for ConTeXt mode (bug#70811)

* context.el (ConTeXt-paragraph-commands): New customize option similar
to LaTeX counterpart.
(ConTeXt-extra-paragraph-commands): Provide proper defvar.
(ConTeXt-paragraph-commands-regexp-make): Rename from
`ConTeXt-paragraph-commands-regexp' for consistency with latex.el.
Include `ConTeXt-paragraph-commands' to generate the regexp.
(ConTeXt-paragraph-commands-regexp): Add alias for backward
compatibility.
(ConTeXt-set-paragraph-start): Factor out following latex.el.
(ConTeXt-paragraph-commands-add-locally): New convinience function
similar to LaTeX counterpart.
(ConTeXt-mode-cleanup): Use new functions.
---
 context.el | 63 +++---
 1 file changed, 48 insertions(+), 15 deletions(-)

diff --git a/context.el b/context.el
index 0d5b9adbd1..8b0c88ee64 100644
--- a/context.el
+++ b/context.el
@@ -53,9 +53,6 @@
 (require 'latex) ; for functions like `TeX-look-at' and `LaTeX-split-long-menu'
 (require 'plain-tex) ; for `plain-TeX-common-initialization'
 
-;; Silence the compiler:
-(defvar ConTeXt-extra-paragraph-commands)
-
 (defgroup ConTeXt-macro nil
   "Special support for ConTeXt macros in AUCTeX."
   :prefix "TeX-"
@@ -1121,18 +1118,59 @@ If OPTIONAL, only insert it if not empty, and then use 
square brackets."
 (defvar ConTeXt-item-list ()
   "List of macro's considered items.")
 
-(defun ConTeXt-paragraph-commands-regexp ()
-  "Return a regexp matching macros that should have their own line."
+(defvar ConTeXt-extra-paragraph-commands nil
+  "List of default ConTeXt macros that should begin their own line.
+Unlike `ConTeXt-paragraph-commands', each entry should be a regular
+expression without leading backslash.
+Updated in language-specific initialization.")
+
+(defcustom ConTeXt-paragraph-commands nil
+  "List of user ConTeXt macros that should begin their own line.
+The list should contain macro names without the leading backslash.
+
+If you change this variable, its value is reflected to only new buffers
+created afterwards; existing ConTeXt mode buffers aren't affected."
+  :group 'ConTeXt-macro
+  :type '(repeat (string)))
+
+(defun ConTeXt-paragraph-commands-regexp-make ()
+  "Return a regexp matching macros that should begin their own line."
   (concat
-   (regexp-quote TeX-esc) "\\("
+   (regexp-quote TeX-esc) "\\(?:"
"[][]\\|"  ; display math delimitors (is this applicable to ConTeXt??)
(ConTeXt-environment-start-name) "\\|"
(ConTeXt-environment-stop-name) "\\|"
(mapconcat #'car ConTeXt-numbered-section-list "\\b\\|") "\\b\\|"
(mapconcat #'car ConTeXt-unnumbered-section-list "\\b\\|") "\\b\\|"
+   (mapconcat #'identity ConTeXt-paragraph-commands "\\b\\|") "\\b\\|"
(mapconcat #'identity ConTeXt-extra-paragraph-commands "\\b\\|")
"\\b\\|"
(mapconcat #'identity ConTeXt-item-list "\\b\\|") "\\b\\)"))
+;; Backward compatibility.
+(defalias 'ConTeXt-paragraph-commands-regexp
+  #'ConTeXt-paragraph-commands-regexp-make)
+
+(defun ConTeXt-set-paragraph-start ()
+  "Set `paragraph-start'."
+  (setq paragraph-start
+(concat
+ "[ \t]*\\(?:"
+ LaTeX-paragraph-commands-regexp "\\|"
+ "\\$\\$\\|" ; Plain TeX display math
+ "$\\)")))
+
+(defun ConTeXt-paragraph-commands-add-locally (commands)
+  "Make COMMANDS be recognized as paragraph commands.
+COMMANDS can be a single string or a list of strings which will be added
+to `ConTeXt-extra-paragraph-commands'.  Additionally
+`LaTeX-paragraph-commands-regexp' will be updated.
+This is mainly a convenience function which can be used in style files."
+  (unless (listp commands) (setq commands (list commands)))
+  (dolist (elt commands)
+(add-to-list 'ConTeXt-extra-paragraph-commands elt))
+  (setq-local LaTeX-paragraph-commands-regexp
+  (ConTeXt-paragraph-commands-regexp-make))
+  (ConTeXt-set-paragraph-start))
 
 
 ;; Outline support
@@ -1908,16 +1946,11 @@ Run after mode hooks and file local variables 
application."
(mapconcat #'identity ConTeXt-item-list "\\|")
"\\)\\>")))
 
-  ;; Don't do locally-bound test for `LaTeX-paragraph-commands-regexp'
-  ;; and `paragraph-start'.  See comments in similar part in latex.el.
   (setq-local LaTeX-paragraph-commands-regexp
-  (ConTeXt-paragraph-commands-regexp))
-  (setq paragraph-start
-(concat
- "[ \t]*\\("
- (ConTeXt-paragraph-commands-regexp) "\\|"
- "\\$\\$\\|" ; Plain TeX display math
- "$\\)")))
+  (ConTeXt-paragraph-commands-regexp-make))
+  ;; Don't do locally-bound test for `paragraph-start'.  See comments in
+  ;; similar part in latex.el.
+  (ConTeXt-set-paragraph-start))
 
 (defun context-guess-current-interface ()
   "Guess what Co

[elpa] externals/consult updated (22d759c133 -> 6eba1a3fa8)

2024-05-15 Thread ELPA Syncer
elpasync pushed a change to branch externals/consult.

  from  22d759c133 Do not use xref--group-name-for-display (Fix #1015)
   new  9387802ff9 Update changelog
   new  6eba1a3fa8 Version 1.6


Summary of changes:
 CHANGELOG.org | 4 +++-
 consult.el| 2 +-
 2 files changed, 4 insertions(+), 2 deletions(-)



[elpa] externals/auctex 59ddea9f13 04/13: Correct variable name

2024-05-15 Thread ELPA Syncer
branch: externals/auctex
commit 59ddea9f134e1c16206749b38314a47acde680de
Author: Arash Esbati 
Commit: Arash Esbati 

Correct variable name

* latex.el (TeX-normal-mode-reset-list): Fix the name of the
variable added to the list which is `LaTeX-global-class-files'.
Reported by Werner Fink .
---
 latex.el | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/latex.el b/latex.el
index 5c6a851089..acdb5f7366 100644
--- a/latex.el
+++ b/latex.el
@@ -2714,7 +2714,7 @@ Initialized once at the first time you prompt for a LaTeX 
class.
 May be reset with `\\[universal-argument] \\[TeX-normal-mode]'.")
 
 ;; Add the variable to `TeX-normal-mode-reset-list':
-(add-to-list 'TeX-normal-mode-reset-list 'TeX-global-class-files)
+(add-to-list 'TeX-normal-mode-reset-list 'LaTeX-global-class-files)
 
 (defcustom TeX-arg-input-file-search t
   "If `TeX-arg-input-file' should search for files.



[elpa] externals/consult 6eba1a3fa8 2/2: Version 1.6

2024-05-15 Thread ELPA Syncer
branch: externals/consult
commit 6eba1a3fa8e13681091a30b2490a03bdce5f243a
Author: Daniel Mendler 
Commit: Daniel Mendler 

Version 1.6
---
 CHANGELOG.org | 2 +-
 consult.el| 2 +-
 2 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/CHANGELOG.org b/CHANGELOG.org
index 78c0a99567..2fdc9337a7 100644
--- a/CHANGELOG.org
+++ b/CHANGELOG.org
@@ -2,7 +2,7 @@
 #+author: Daniel Mendler
 #+language: en
 
-* Development
+* Version 1.6 (2024-05-15)
 
 - ~consult-xref~: Compatibility with xref.el in Emacs 30.
 - ~consult-grep~ (and similar): Preserve files which are already open literally
diff --git a/consult.el b/consult.el
index 7966bea18e..c13266f393 100644
--- a/consult.el
+++ b/consult.el
@@ -5,7 +5,7 @@
 ;; Author: Daniel Mendler and Consult contributors
 ;; Maintainer: Daniel Mendler 
 ;; Created: 2020
-;; Version: 1.5
+;; Version: 1.6
 ;; Package-Requires: ((emacs "27.1") (compat "29.1.4.4"))
 ;; Homepage: https://github.com/minad/consult
 ;; Keywords: matching, files, completion



[elpa] externals/auctex 543d92aa89 13/13: Merge remote-tracking branch 'origin/master'

2024-05-15 Thread ELPA Syncer
branch: externals/auctex
commit 543d92aa89ff17c3c56bbd677042a78006b67ac4
Merge: 5a64a805e5 e30189d92a
Author: Tassilo Horn 
Commit: Tassilo Horn 

Merge remote-tracking branch 'origin/master'
---
 NEWS.org | 153 +++-
 context.el   |  63 +
 latex.el |   2 +-
 style/amsrefs.el | 234 +
 style/moodle.el  | 263 ---
 tex.el   |  14 ++-
 6 files changed, 576 insertions(+), 153 deletions(-)

diff --git a/NEWS.org b/NEWS.org
index 10e890e0e3..451056a777 100644
--- a/NEWS.org
+++ b/NEWS.org
@@ -6,7 +6,7 @@
 # License: GNU General Public License 3
 # The format is based on [[https://keepachangelog.com/en/1.1.0/][Keep a 
Changelog]]
 
-* [Unreleased]
+* [14.0.5] - 2024-05-19
 
 ** Added
 
@@ -22,19 +22,27 @@
   hides all configured macros in the section containing point when
   ~TeX-fold-mode~ is active.  The unfold counterpart
   ~TeX-fold-clearout-section~ is bound to =C-c C-o s=.
-- Add new custom option ~TeX-fold-auto-reveal~ which contols how the
-  original source text is revealed when user clicks the folded portion
-  by mouse.
 - Add new custom option ~TeX-fold-region-functions~ which is a list of
   additional functions to call when folding a region.
+- Add new custom option ~TeX-fold-auto-reveal~ which controls how the
+  original source text is revealed when user clicks the folded portion
+  by mouse.
+- Add new custom options ~TeX-fold-auto-reveal-commands~ and
+  ~preview-auto-reveal-commands~ which are lists of commands revealing
+  folded or previewed buffer text.
 - Add new custom option ~preview-protect-point~ which determines whether
   previews generated on top of the current point should be temporarily
   opened (~nil~ by default).
 - Add new custom option ~preview-leave-open-previews-visible~ which
   determines if the preview code stays visible once opened.
+- Change the default value of ~TeX-one-master~ in order to recognize the
+  suffix =.ltx= as regular TeX files.
+- Add new custom option ~ConTeXt-paragraph-commands~ containing a list
+  of macros which should begin their own line.
 - Support query and insert of ~mcite~ compatibility macro
   (=style/biblatex.el=).
 - Support the =\verbatiminput*= macro (=style/verbatim.el=).
+- Add new support file =style/amsrefs.el=.
 
 ** Fixed
 
@@ -62,3 +70,140 @@
 
 - Revert usage of ~:local~ tag inside ~defcustom~.  This tag isn't
   handled correctly in Emacs 27.1 and breaks AUCTeX.
+
+* [14.0.3] - 2024-02-20
+
+** Fixed
+
+- Cater for former mode name in customized ~TeX-command-list~.
+- Fix and enhance pseudo-parent mode facility.
+
+* [14.0.2] - 2024-02-09
+
+** Fixed
+
+- Fix ELPA releases.
+
+* [14.0.1] - 2024-02-08
+
+** Added
+
+- AUCTeX changes major mode names.  Its primary purpose is to avoid
+  conflicts with Emacs built-in TeX major modes.  It also improves
+  consistency of the source code.
+  - The overview of the former names and new names are:
+| Former name   | New name  |
+|---+---|
+| ~plain-tex-mode~  | ~plain-TeX-mode~  |
+| ~latex-mode~  | ~LaTeX-mode~  |
+| ~doctex-mode~ | ~docTeX-mode~ |
+| ~texinfo-mode~| ~Texinfo-mode~|
+| ~ams-tex-mode~| ~AmSTeX-mode~ |
+| ~japanese-plain-tex-mode~ | ~japanese-plain-TeX-mode~ |
+| ~japanese-latex-mode~ | ~japanese-LaTeX-mode~ |
+
+The undocumented modes ~context-en-mode~ and ~context-nl-mode~ were
+deleted.
+  - We paid much attention to the compatibility and expect that almost
+no particular treatment on the user side is needed.  For example,
+the names of the keymaps and mode hooks remain unchanged, and the
+=mode:= tag in the file local variables in the existing files works
+with old mode names.  See below for more details
+  - If your Emacs is 29 or newer and you use =desktop.el= to save and
+restore Emacs sessions, be careful before you update AUCTeX; You
+should attempt to update only after
+1. you kill all buffer under former AUCTeX modes which have
+   overlapped name with Emacs built-in TeX modes, and
+2. you terminate the current Emacs session.
+The modes with such overlapped name are ~plain-tex-mode~,
+~latex-mode~, ~doctex-mode~ and ~texinfo-mode~.  (The above
+prescription ensures no buffer of such modes is recorded in the
+desktop file.  Otherwise those buffers would be restored in the
+built-in modes, not AUCTeX modes, after the update of AUCTeX.)
+  - New mode names are chosen to match the existing variables, so most
+user customizations as well as the third party libraries would
+continue to work without modification.  For example, names of
+keymaps and hooks don't change as stated above.
+(~AmS-TeX-

[elpa] externals/auctex 5f039df961 02/13: ; * NEWS.org: Update the file.

2024-05-15 Thread ELPA Syncer
branch: externals/auctex
commit 5f039df961e910402f4a8b742cc2f82371f2e688
Author: Arash Esbati 
Commit: Arash Esbati 

; * NEWS.org: Update the file.
---
 NEWS.org | 11 ---
 1 file changed, 8 insertions(+), 3 deletions(-)

diff --git a/NEWS.org b/NEWS.org
index 10e890e0e3..f0649d6f59 100644
--- a/NEWS.org
+++ b/NEWS.org
@@ -22,16 +22,21 @@
   hides all configured macros in the section containing point when
   ~TeX-fold-mode~ is active.  The unfold counterpart
   ~TeX-fold-clearout-section~ is bound to =C-c C-o s=.
-- Add new custom option ~TeX-fold-auto-reveal~ which contols how the
-  original source text is revealed when user clicks the folded portion
-  by mouse.
 - Add new custom option ~TeX-fold-region-functions~ which is a list of
   additional functions to call when folding a region.
+- Add new custom option ~TeX-fold-auto-reveal~ which controls how the
+  original source text is revealed when user clicks the folded portion
+  by mouse.
+- Add new custom options ~TeX-fold-auto-reveal-commands~ and
+  ~preview-auto-reveal-commands~ which are lists of commands revealing
+  folded or previewed buffer text.
 - Add new custom option ~preview-protect-point~ which determines whether
   previews generated on top of the current point should be temporarily
   opened (~nil~ by default).
 - Add new custom option ~preview-leave-open-previews-visible~ which
   determines if the preview code stays visible once opened.
+- Change the default value of ~TeX-one-master~ in order to recognize the
+  suffix =.ltx= as regular TeX files.
 - Support query and insert of ~mcite~ compatibility macro
   (=style/biblatex.el=).
 - Support the =\verbatiminput*= macro (=style/verbatim.el=).



[elpa] externals/auctex 1d66dd1f6f 01/13: Enable lexical-binding in auto-generated styles

2024-05-15 Thread ELPA Syncer
branch: externals/auctex
commit 1d66dd1f6f047c05f0802b58c1924ec1f9700fd9
Author: Arash Esbati 
Commit: Arash Esbati 

Enable lexical-binding in auto-generated styles

* tex.el (TeX-auto-store): Add lexical cookie to auto-generated
style files.
---
 tex.el | 1 +
 1 file changed, 1 insertion(+)

diff --git a/tex.el b/tex.el
index cda1d7f646..0dec8568b9 100644
--- a/tex.el
+++ b/tex.el
@@ -4267,6 +4267,7 @@ If TEX is a directory, generate style files for all files 
in the directory."
 (TeX-unload-style style)
 (with-current-buffer (generate-new-buffer file)
   (erase-buffer)
+  (insert ";; -*- lexical-binding: t; -*-\n\n")
   (insert "(TeX-add-style-hook\n \""
   style "\"\n (lambda ()")
   (unless (string= tex-cmd-opts "")



[elpa] externals/consult 9387802ff9 1/2: Update changelog

2024-05-15 Thread ELPA Syncer
branch: externals/consult
commit 9387802ff945151ba2337666b90c317619372215
Author: Daniel Mendler 
Commit: Daniel Mendler 

Update changelog
---
 CHANGELOG.org | 2 ++
 1 file changed, 2 insertions(+)

diff --git a/CHANGELOG.org b/CHANGELOG.org
index a3d10d3ee1..78c0a99567 100644
--- a/CHANGELOG.org
+++ b/CHANGELOG.org
@@ -4,10 +4,12 @@
 
 * Development
 
+- ~consult-xref~: Compatibility with xref.el in Emacs 30.
 - ~consult-grep~ (and similar): Preserve files which are already open literally
   and do not reopen them in normal mode.
 - ~consult-preview-allowed-hooks~: Run delayed mode hooks listed in this 
variable
   during preview.
+- ~consult--buffer-query~: Add buffer-list keyword argument.
 
 * Version 1.5 (2024-04-19)
 



[elpa] externals/auctex cba5820cf8 03/13: Allow compilation messages to be suppressed

2024-05-15 Thread ELPA Syncer
branch: externals/auctex
commit cba5820cf80ca46b08956d7f94f9b98e0e222db8
Author: Paul Nelson 
Commit: Arash Esbati 

Allow compilation messages to be suppressed

* tex.el (TeX-suppress-compilation-message): New variable.
(TeX-run-command): Use it.  (bug#70783)
---
 tex.el | 10 +++---
 1 file changed, 7 insertions(+), 3 deletions(-)

diff --git a/tex.el b/tex.el
index 0dec8568b9..e13c02ce17 100644
--- a/tex.el
+++ b/tex.el
@@ -7997,6 +7997,9 @@ requires special treatment."
   :group 'TeX-command
   :type 'boolean)
 
+(defvar TeX-suppress-compilation-message nil
+  "If non-nil, suppress \"display results of compilation\" message.")
+
 (defun TeX-run-command (name command file)
   "Create a process for NAME using COMMAND to process FILE.
 Return the new process."
@@ -8018,9 +8021,10 @@ Return the new process."
 (TeX-output-mode)
 (if TeX-show-compilation
 (display-buffer buffer)
-  (message "Type `%s' to display results of compilation."
-   (substitute-command-keys
-"[TeX-recenter-output-buffer]")))
+  (unless TeX-suppress-compilation-message
+(message "Type `%s' to display results of compilation."
+ (substitute-command-keys
+  "[TeX-recenter-output-buffer]"
 (setq TeX-parse-function #'TeX-parse-command)
 (setq TeX-command-default default)
 (setq TeX-sentinel-function



[elpa] externals/auctex 61f8825cfd 05/13: Add new style/amsrefs.el

2024-05-15 Thread ELPA Syncer
branch: externals/auctex
commit 61f8825cfdd2d3746e7d85e0d9c91811d0ec3d38
Author: Arash Esbati 
Commit: Arash Esbati 

Add new style/amsrefs.el

* Makefile.in (STYLESRC): Add new style.

* style/amsrefs.el: New file.
---
 Makefile.in  |   2 +-
 style/amsrefs.el | 233 +++
 2 files changed, 234 insertions(+), 1 deletion(-)

diff --git a/Makefile.in b/Makefile.in
index bc2ea9510f..9dcb3d7b66 100644
--- a/Makefile.in
+++ b/Makefile.in
@@ -198,7 +198,7 @@ STYLESRC = style/prosper.el \
   style/amsaddr.el   style/parskip.el   style/catchfilebetweentags.el \
   style/physics.el   style/soul.el  style/algpseudocodex.el \
   style/wasysym.el   style/refcount.el  style/simpleicons.el \
-  style/changebar.el
+  style/changebar.el style/amsrefs.el
 
 STYLEELC = $(STYLESRC:.el=.elc)
 
diff --git a/style/amsrefs.el b/style/amsrefs.el
new file mode 100644
index 00..babfebb12b
--- /dev/null
+++ b/style/amsrefs.el
@@ -0,0 +1,233 @@
+;;; amsrefs.el --- AUCTeX style for `amsrefs.sty'  -*- lexical-binding: t; -*-
+
+;; Copyright (C) 2024 Free Software Foundation, Inc.
+
+;; Author: Arash Esbati 
+;; Maintainer: auctex-de...@gnu.org
+;; Created: 2024-02-21
+;; Keywords: tex
+
+;; This file is part of AUCTeX.
+
+;; AUCTeX is free software; you can redistribute it and/or modify it
+;; under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 3, or (at your option)
+;; any later version.
+
+;; AUCTeX is distributed in the hope that it will be useful, but
+;; WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+;; General Public License for more details.
+
+;; You should have received a copy of the GNU General Public License
+;; along with AUCTeX; see the file COPYING.  If not, write to the Free
+;; Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+;; MA 02110-1301 USA.
+
+;;; Commentary:
+
+;; This file adds support for `amsrefs.sty' form 2013-01-16.
+
+;;; Code:
+
+(require 'tex)
+(require 'latex)
+
+;; Silence the compiler:
+(declare-function font-latex-add-keywords
+  "font-latex"
+  (keywords class))
+
+(defun LaTeX-item-amsrefs-bib ()
+  "Insert a new bib item from the amsrefs package."
+  (TeX-insert-macro "bib"))
+
+(defun LaTeX-env-amsrefs-biblist (_environment)
+  "Ignore ENVIRONMENT and insert a \"biblist\" environment with arguments."
+  (let ((opt (TeX-read-string
+  (TeX-argument-prompt t nil "argument")))
+(keyvals (unless (LaTeX-provided-class-options-member "amsrefs"
+  "author-year")
+   (TeX-read-key-val t '(("labels" ("numeric" "alphabetic"
+"shortalphabetic"))
+ ("prefix"))
+(LaTeX-insert-environment "biblist"
+  (concat (unless (string-empty-p opt)
+(concat LaTeX-optop opt LaTeX-optcl))
+  (unless (string-empty-p keyvals)
+(concat "*" TeX-grop keyvals 
TeX-grcl)
+  (end-of-line 0)
+  (delete-char 1)
+  (delete-horizontal-space)
+  (LaTeX-insert-item))
+
+(defvar LaTeX-amsrefs-bib-regexp
+  `(,(concat "bib\\*?{\\(" TeX-token-char "[^, \n\r\t%\"#'()={}]*\\)}")
+1 LaTeX-auto-bibitem)
+  "Matches the cite key after the \\bib macro.")
+
+(defvar LaTeX-amsrefs-bib-key-val
+  '(;; Simple fields
+("accessdate")
+("address")
+("booktitle")
+("date")
+("edition")
+("eprint")
+("hyphenation")
+("journal")
+("label")
+("language")
+("note")
+("number")
+("organization")
+("pages")
+("part")
+("publisher")
+("series")
+("status")
+("subtitle")
+("title")
+("type")
+("volume")
+;; Repeatable fields
+("author")
+("editor")
+("translator")
+("isbn")
+("issn")
+("review")
+;; Compound fields: Not support by key=val system
+("book" ("{}"))
+("conference" ("{}"))
+("contribution" ("{}"))
+("partial" ("{}"))
+("reprint" ("{}"))
+("translation" ("{}")))
+  "Key=val options for the \\bib macro from amsrefs package.")
+
+(defun LaTeX-amsrefs-bib-key-val ()
+  "Return an updated list of key=vals for the amsrefs package."
+  (append `(("xref" ,(mapcar #'car (LaTeX-bibitem-list
+  LaTeX-amsrefs-bib-key-val))
+
+(TeX-add-style-hook
+ "amsrefs"
+ (lambda ()
+
+   ;; Add the entry to the parser
+   (TeX-auto-add-regexp LaTeX-amsrefs-bib-regexp)
+
+   ;; 3 The biblist and biblist* environments
+   (LaTeX-add-environments
+'("bibdiv")
+'("biblist" LaTeX-env-amsrefs-biblist))
+
+   (TeX-add-symbols
+;; 5 More about the \bib 

[elpa] externals/auctex e30189d92a 12/13: ; * NEWS.org: Update for 14.0.5 ELPA release.

2024-05-15 Thread ELPA Syncer
branch: externals/auctex
commit e30189d92a701ab22a69a09fe2b9e9619fff6ce8
Author: Arash Esbati 
Commit: Arash Esbati 

; * NEWS.org: Update for 14.0.5 ELPA release.
---
 NEWS.org | 5 -
 1 file changed, 4 insertions(+), 1 deletion(-)

diff --git a/NEWS.org b/NEWS.org
index 7a21f22730..451056a777 100644
--- a/NEWS.org
+++ b/NEWS.org
@@ -6,7 +6,7 @@
 # License: GNU General Public License 3
 # The format is based on [[https://keepachangelog.com/en/1.1.0/][Keep a 
Changelog]]
 
-* [Unreleased]
+* [14.0.5] - 2024-05-19
 
 ** Added
 
@@ -37,9 +37,12 @@
   determines if the preview code stays visible once opened.
 - Change the default value of ~TeX-one-master~ in order to recognize the
   suffix =.ltx= as regular TeX files.
+- Add new custom option ~ConTeXt-paragraph-commands~ containing a list
+  of macros which should begin their own line.
 - Support query and insert of ~mcite~ compatibility macro
   (=style/biblatex.el=).
 - Support the =\verbatiminput*= macro (=style/verbatim.el=).
+- Add new support file =style/amsrefs.el=.
 
 ** Fixed
 



[elpa] externals/jinx 3c36f1eb31: Version 1.7

2024-05-15 Thread ELPA Syncer
branch: externals/jinx
commit 3c36f1eb31713869ffbdbf55971671efa4f01966
Author: Daniel Mendler 
Commit: Daniel Mendler 

Version 1.7
---
 CHANGELOG.org | 2 +-
 jinx.el   | 2 +-
 2 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/CHANGELOG.org b/CHANGELOG.org
index 01048b86d6..4c4c1f44b9 100644
--- a/CHANGELOG.org
+++ b/CHANGELOG.org
@@ -2,7 +2,7 @@
 #+author: Daniel Mendler
 #+language: en
 
-* Development
+* Version 1.7 (2024-05-15)
 
 - ~jinx--word-valid-p~: Do not error on invalid characters.
 - ~jinx-save-languages~: New custom variable.
diff --git a/jinx.el b/jinx.el
index d8a3ec5bad..76604e43ef 100644
--- a/jinx.el
+++ b/jinx.el
@@ -5,7 +5,7 @@
 ;; Author: Daniel Mendler 
 ;; Maintainer: Daniel Mendler 
 ;; Created: 2023
-;; Version: 1.6
+;; Version: 1.7
 ;; Package-Requires: ((emacs "27.1") (compat "29.1.4.4"))
 ;; Homepage: https://github.com/minad/jinx
 ;; Keywords: convenience, text



[elpa] externals/consult c0d8a12bce 2/2: consult--buffer-sort-visibility: Do not always add the current buffer

2024-05-15 Thread ELPA Syncer
branch: externals/consult
commit c0d8a12bce2568298ff9bcfec1c6cb5e68ca0b61
Author: Daniel Mendler 
Commit: Daniel Mendler 

consult--buffer-sort-visibility: Do not always add the current buffer
---
 consult.el | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/consult.el b/consult.el
index c13266f393..a837d051f1 100644
--- a/consult.el
+++ b/consult.el
@@ -4360,14 +4360,14 @@ The command supports previewing the currently selected 
theme."
 (defun consult--buffer-sort-visibility (buffers)
   "Sort BUFFERS by visibility."
   (let ((hidden)
-(current (current-buffer)))
+(current (car (memq (current-buffer) buffers
 (consult--keep! buffers
   (unless (eq it current)
 (if (get-buffer-window it 'visible)
 it
   (push it hidden)
   nil)))
-(nconc (nreverse hidden) buffers (list current
+(nconc (nreverse hidden) buffers (and current (list current)
 
 (defun consult--normalize-directory (dir)
   "Normalize directory DIR.



[elpa] externals/consult 621f374984 1/2: consult-xref: Handle root=nil

2024-05-15 Thread ELPA Syncer
branch: externals/consult
commit 621f374984788f76d8b9e5f76d05c4da265c8723
Author: Daniel Mendler 
Commit: Daniel Mendler 

consult-xref: Handle root=nil
---
 consult-xref.el | 3 ++-
 1 file changed, 2 insertions(+), 1 deletion(-)

diff --git a/consult-xref.el b/consult-xref.el
index 7d502e44a6..639feaf08e 100644
--- a/consult-xref.el
+++ b/consult-xref.el
@@ -41,7 +41,8 @@ The fetch is stored globally such that it can be accessed by
   (let ((root (consult--project-root)))
 (mapcar (lambda (xref)
   (let* ((loc (xref-item-location xref))
- (group (string-remove-prefix root (xref-location-group 
loc)))
+ (group (xref-location-group loc))
+ (group (if root (string-remove-prefix root group) group))
  (cand (consult--format-file-line-match
 group
 (or (xref-location-line loc) 0)



[elpa] externals/consult updated (6eba1a3fa8 -> c0d8a12bce)

2024-05-15 Thread ELPA Syncer
elpasync pushed a change to branch externals/consult.

  from  6eba1a3fa8 Version 1.6
   new  621f374984 consult-xref: Handle root=nil
   new  c0d8a12bce consult--buffer-sort-visibility: Do not always add the 
current buffer


Summary of changes:
 consult-xref.el | 3 ++-
 consult.el  | 4 ++--
 2 files changed, 4 insertions(+), 3 deletions(-)



[nongnu] elpa/auto-dim-other-buffers f0f1905fdf: Prefer NonGNU ELPA in README

2024-05-15 Thread ELPA Syncer
branch: elpa/auto-dim-other-buffers
commit f0f1905fdf1ca3021e49f220687a4fad2081ba08
Author: Michal Nazarewicz 
Commit: Michal Nazarewicz 

Prefer NonGNU ELPA in README

NonGNU ELPA is included by default in package-archives which makes it
more accessible to users.  adob is still available in MELPA of course
so users can grab it from there as well.
---
 README.md | 15 ---
 1 file changed, 8 insertions(+), 7 deletions(-)

diff --git a/README.md b/README.md
index 1b26a0be25..a9bc7d464d 100644
--- a/README.md
+++ b/README.md
@@ -1,5 +1,6 @@
 # auto-dim-other-buffers.el
 
+[![NonGNU 
ELPA](https://elpa.nongnu.org/nongnu/auto-dim-other-buffers.svg)](https://elpa.nongnu.org/nongnu/auto-dim-other-buffers.html)
 
[![MELPA](https://melpa.org/packages/auto-dim-other-buffers-badge.svg)](https://melpa.org/#/auto-dim-other-buffers)
 
 The `auto-dim-other-buffers-mode` is a global minor mode which makes
@@ -11,28 +12,28 @@ indicator.
 [![Demo](screenshot.gif)](https://www.youtube.com/watch?v=2djOHSWhyD4)
 
 The preferred way to install the mode is by grabbing
-`auto-dim-other-buffers` package form MELPA:
+`auto-dim-other-buffers` package form NonGNU ELPA:
 
 M-x package-install RET auto-dim-other-buffers RET
 
-Once installed, the mode can be turned on (globally) with:
+Once installed, enable the mode with:
 
 M-x auto-dim-other-buffers-mode RET
 
-To make the mode enabled every time Emacs starts, add the following to
-Emacs initialisation file (`~/.emacs` or `~/.emacs.d/init.el`):
+To make it enabled every time Emacs starts, add the following to Emacs
+initialisation file (typically `~/.emacs` or `~/.emacs.d/init.el`):
 
 (add-hook 'after-init-hook (lambda ()
   (when (fboundp 'auto-dim-other-buffers-mode)
 (auto-dim-other-buffers-mode t
 
-To configure how dimmed buffers look like, customise
+To configure how dimmed buffers look, customise
 `auto-dim-other-buffers-face`.  This can be accomplished by:
 
 M-x customize-face RET auto-dim-other-buffers-face RET
 
-More customisation can be found in `auto-dim-other-buffers`
-customisation group which can be accessed with:
+More options can be found in `auto-dim-other-buffers` customisation
+group which can be accessed with:
 
 M-x customize-group RET auto-dim-other-buffers RET
 



[nongnu] elpa/helm 08cfc12278 3/3: Move helm-re-search-forward in helm-lib

2024-05-15 Thread ELPA Syncer
branch: elpa/helm
commit 08cfc12278991e5a62a3b7aeedb4adef420a3662
Author: Thierry Volpiatto 
Commit: Thierry Volpiatto 

Move helm-re-search-forward in helm-lib
---
 helm-core.el | 9 -
 helm-lib.el  | 9 +
 2 files changed, 9 insertions(+), 9 deletions(-)

diff --git a/helm-core.el b/helm-core.el
index 29bdff4b74..7dbce040eb 100644
--- a/helm-core.el
+++ b/helm-core.el
@@ -4658,15 +4658,6 @@ useful when the order of the candidates is meaningful, 
e.g. with
   (char-fold-to-regexp pattern)
 pattern)))
 
-(defun helm-re-search-forward (regexp &optional bound noerror count)
-  "Same as `re-search-forward' but return nil when point doesn't move.
-This avoid possible infloop when a wrong regexp is entered in minibuffer."
-  ;; See Issue#2652 and Issue#2653.
-  (let ((pos (point)))
-(helm-acase (re-search-forward regexp bound noerror count)
-  ((guard (eql it pos)) nil)
-  (t it
-
 (defun helm-fuzzy-default-highlight-match-1 (candidate &optional pattern 
diacritics file-comp)
   (let* ((pair(and (consp candidate) candidate))
  (display (helm-stringify (if pair (car pair) candidate)))
diff --git a/helm-lib.el b/helm-lib.el
index 392f9171ca..0053e60021 100644
--- a/helm-lib.el
+++ b/helm-lib.el
@@ -1339,6 +1339,15 @@ used to modify each element of LIST to be displayed in 
PROMPT."
   (cl-assert (stringp str) t)
   (or (cl-loop for c across str always (char-equal c ?0))
   (not (zerop (string-to-number str)
+
+(defun helm-re-search-forward (regexp &optional bound noerror count)
+  "Same as `re-search-forward' but return nil when point doesn't move.
+This avoid possible infloop when a wrong regexp is entered in minibuffer."
+  ;; See Issue#2652 and Issue#2653.
+  (let ((pos (point)))
+(helm-acase (re-search-forward regexp bound noerror count)
+  ((guard (eql it pos)) nil)
+  (t it
 
 ;;; Symbols routines
 ;;



[nongnu] elpa/helm-core updated (6d23a65ca6 -> 08cfc12278)

2024-05-15 Thread ELPA Syncer
elpasync pushed a change to branch elpa/helm-core.

  from  6d23a65ca6 Don't use cache in HFF with unsupported tramp methods 
(#2668)
  adds  b5a75f49f9 Prefer helm-position over cl-position
  adds  44e9ce6857 Ensure to not use non image files in slideshow
  adds  08cfc12278 Move helm-re-search-forward in helm-lib

No new revisions were added by this update.

Summary of changes:
 helm-core.el  |  9 -
 helm-files.el | 51 +++
 helm-lib.el   | 11 ++-
 3 files changed, 37 insertions(+), 34 deletions(-)



[nongnu] elpa/helm b5a75f49f9 1/3: Prefer helm-position over cl-position

2024-05-15 Thread ELPA Syncer
branch: elpa/helm
commit b5a75f49f9393f33633daa62e6957fbb9a14d94b
Author: Thierry Volpiatto 
Commit: Thierry Volpiatto 

Prefer helm-position over cl-position
---
 helm-files.el | 2 +-
 helm-lib.el   | 2 +-
 2 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/helm-files.el b/helm-files.el
index 349c57e843..772ca72154 100644
--- a/helm-files.el
+++ b/helm-files.el
@@ -5151,7 +5151,7 @@ Special commands:
 
 (defun helm-ff-slideshow-state ()
   (format "(%s/%s) "
-  (1+ (cl-position
+  (1+ (helm-position
(buffer-file-name) helm-ff--slideshow-sequence
:test 'equal))
   (length helm-ff--slideshow-sequence)))
diff --git a/helm-lib.el b/helm-lib.el
index 69796988e5..392f9171ca 100644
--- a/helm-lib.el
+++ b/helm-lib.el
@@ -1137,7 +1137,7 @@ Examples:
   (let* ((new-seq  (if reverse
(reverse sequence)
  sequence))
- (pos  (1+ (cl-position elm new-seq :test 'equal
+ (pos  (1+ (helm-position elm new-seq :test 'equal
 (append (nthcdr pos new-seq) (helm-take new-seq pos
 
 ;;; Strings processing.



[nongnu] elpa/helm 44e9ce6857 2/3: Ensure to not use non image files in slideshow

2024-05-15 Thread ELPA Syncer
branch: elpa/helm
commit 44e9ce6857a1cc0159d1ee0b0fde53660fd0a6dc
Author: Thierry Volpiatto 
Commit: Thierry Volpiatto 

Ensure to not use non image files in slideshow
---
 helm-files.el | 49 ++---
 1 file changed, 26 insertions(+), 23 deletions(-)

diff --git a/helm-files.el b/helm-files.el
index 772ca72154..5fd28ff4f5 100644
--- a/helm-files.el
+++ b/helm-files.el
@@ -5079,28 +5079,29 @@ file."
  finally do (setq helm-ff--image-cache nil
 
 (defun helm-ff--display-image-native (candidate)
-  (when (buffer-live-p (get-buffer helm-ff-image-native-buffer))
-(kill-buffer helm-ff-image-native-buffer))
-  ;; Avoid hight memory consumption see
-  ;; https://lists.gnu.org/archive/html/bug-gnu-emacs/2021-11/msg00879.html.
-  (when (> (length helm-ff--image-cache)
-   (* helm-ff-image-cache-max-len 2))
-;; Only keep the last `helm-ff-image-cache-max-len' images in cache.
-(cl-loop for img in (butlast helm-ff--image-cache
- (1+ helm-ff-image-cache-max-len))
- do (clear-image-cache img)
- (setq helm-ff--image-cache
-   (delete img helm-ff--image-cache
-  (cl-letf* (((symbol-function 'message) #'ignore)
- (buf (find-file-noselect candidate t)))
-;; When going back reuse the cached images.
-(unless (member candidate helm-ff--image-cache)
-  (setq helm-ff--image-cache
-(append helm-ff--image-cache
-(list (expand-file-name candidate)
-(with-current-buffer buf
-  (rename-buffer helm-ff-image-native-buffer))
-(display-buffer buf)))
+  (when (string-match-p (image-file-name-regexp) candidate)
+(when (buffer-live-p (get-buffer helm-ff-image-native-buffer))
+  (kill-buffer helm-ff-image-native-buffer))
+;; Avoid hight memory consumption see
+;; https://lists.gnu.org/archive/html/bug-gnu-emacs/2021-11/msg00879.html.
+(when (> (length helm-ff--image-cache)
+ (* helm-ff-image-cache-max-len 2))
+  ;; Only keep the last `helm-ff-image-cache-max-len' images in cache.
+  (cl-loop for img in (butlast helm-ff--image-cache
+   (1+ helm-ff-image-cache-max-len))
+   do (clear-image-cache img)
+   (setq helm-ff--image-cache
+ (delete img helm-ff--image-cache
+(cl-letf* (((symbol-function 'message) #'ignore)
+   (buf (find-file-noselect candidate t)))
+  ;; When going back reuse the cached images.
+  (unless (member candidate helm-ff--image-cache)
+(setq helm-ff--image-cache
+  (append helm-ff--image-cache
+  (list (expand-file-name candidate)
+  (with-current-buffer buf
+(rename-buffer helm-ff-image-native-buffer))
+  (display-buffer buf
 
 ;;; Slideshow action
 ;;
@@ -5137,7 +5138,9 @@ Special commands:
 
 (defun helm-ff-start-slideshow-on-marked (_candidate)
   "Start a slideshow on marked files."
-  (let ((marked (helm-marked-candidates :with-wildcard t)))
+  (let ((marked (helm-remove-if-not-match
+ (image-file-name-regexp)
+ (helm-marked-candidates :with-wildcard t
 (cl-assert (cdr marked) nil "Can't start a slideshow on a single file")
 (setq helm-ff--slideshow-sequence marked)
 (setq helm-ff--slideshow-iterator (helm-iter-circular marked))



[nongnu] elpa/helm updated (6d23a65ca6 -> 08cfc12278)

2024-05-15 Thread ELPA Syncer
elpasync pushed a change to branch elpa/helm.

  from  6d23a65ca6 Don't use cache in HFF with unsupported tramp methods 
(#2668)
   new  b5a75f49f9 Prefer helm-position over cl-position
   new  44e9ce6857 Ensure to not use non image files in slideshow
   new  08cfc12278 Move helm-re-search-forward in helm-lib


Summary of changes:
 helm-core.el  |  9 -
 helm-files.el | 51 +++
 helm-lib.el   | 11 ++-
 3 files changed, 37 insertions(+), 34 deletions(-)



[nongnu] elpa/org-contrib 8e32471fc8: ox-taskjuggler.el: Update

2024-05-15 Thread ELPA Syncer
branch: elpa/org-contrib
commit 8e32471fc8d7b4edc07e416488e55f0f33c86f23
Author: Harold Ollivier 
Commit: Bastien Guerry 

ox-taskjuggler.el: Update

* lisp/ox-taskjuggler.el (org-taskjuggler-report-tag): New option.
(org-taskjuggler-valid-resource-attributes): New argument.
(org-taskjuggler-valid-account-attributes): New option.
(org-taskjuggler-valid-report-attributes): New arguments.
(org-taskjuggler-assign-account-ids): New function.
(org-taskjuggler-get-end): Use `org-taskjuggler-valid-task-attributes'.
(org-taskjuggler-project-plan): Use `org-taskjuggler-account-tag'.
(org-taskjuggler-project-plan): Rewrite.
(org-taskjuggler--build-account): New function.
(org-taskjuggler--build-report): Update.
---
 lisp/ox-taskjuggler.el | 238 ++---
 1 file changed, 165 insertions(+), 73 deletions(-)

diff --git a/elisp-benchmarks.el b/elisp-benchmarks.el
index 0e2d9dcbc5..c801416989 100644
--- a/elisp-benchmarks.el
+++ b/elisp-benchmarks.el
@@ -4,7 +4,7 @@
 
 ;; Author: Andrea Corallo 
 ;; Maintainer: Andrea Corallo 
-;; Version: 1.14
+;; Version: 1.15
 ;; Keywords: languages, lisp
 ;; Package-Type: multi
 ;; Created: 2019-01-12



[elpa] externals/elisp-benchmarks fccb7bbaad 1/2: * Handle 'compilation-safety'

2024-05-15 Thread Andrea Corallo
branch: externals/elisp-benchmarks
commit fccb7bbaad77f5b77f98bafb8402dbc250e5d9c2
Author: Andrea Corallo 
Commit: Andrea Corallo 

* Handle 'compilation-safety'

* elisp-benchmarks.el (bytecomp): Require it.
: Silence warning if 'compilation-safety' is not defined.
(elb-safety): Define.
(elisp-benchmarks-run): Make use of.
---
 elisp-benchmarks.el | 8 
 1 file changed, 8 insertions(+)

diff --git a/elisp-benchmarks.el b/elisp-benchmarks.el
index 855d5af444..0e2d9dcbc5 100644
--- a/elisp-benchmarks.el
+++ b/elisp-benchmarks.el
@@ -46,9 +46,12 @@
 (require 'benchmark)
 (require 'outline)
 (require 'org)
+(require 'bytecomp)
 (if (featurep 'native-compile)
 (require 'comp)
   (defvar native-comp-speed))
+(unless (boundp 'compilation-safety)
+  (defvar compilation-safety))
 
 (defgroup elb nil
   "Emacs Lisp benchmarks."
@@ -62,6 +65,10 @@
   "Default `native-comp-speed' to be used for native compiling the benchmarks."
   :type 'number)
 
+(defcustom elb-safety 0
+  "Default `compilation-safety' to be used for native compiling the 
benchmarks."
+  :type 'number)
+
 (defconst elb-bench-directory
   (expand-file-name "benchmarks/"
(file-name-directory
@@ -93,6 +100,7 @@ RECOMPILE all the benchmark folder when non nil."
(when current-prefix-arg
  (list (read-regexp "Run benchmark matching: "
   (let* ((native-comp-speed elb-speed)
+(compilation-safety elb-safety)
 (compile-function (if (featurep 'native-compile)
   #'native-compile
 #'byte-compile-file))



[elpa] externals/elisp-benchmarks 0eb498f77b: * elisp-benchmarks.el (native-comp-speed, compilation-safety): Fix warning.

2024-05-15 Thread Andrea Corallo
branch: externals/elisp-benchmarks
commit 0eb498f77b5078849231468848ad73185989185e
Author: Andrea Corallo 
Commit: Andrea Corallo 

* elisp-benchmarks.el (native-comp-speed, compilation-safety): Fix warning.
---
 elisp-benchmarks.el | 7 ++-
 1 file changed, 2 insertions(+), 5 deletions(-)

diff --git a/elisp-benchmarks.el b/elisp-benchmarks.el
index c801416989..abbce4d236 100644
--- a/elisp-benchmarks.el
+++ b/elisp-benchmarks.el
@@ -47,11 +47,8 @@
 (require 'outline)
 (require 'org)
 (require 'bytecomp)
-(if (featurep 'native-compile)
-(require 'comp)
-  (defvar native-comp-speed))
-(unless (boundp 'compilation-safety)
-  (defvar compilation-safety))
+(defvar native-comp-speed)
+(defvar compilation-safety)
 
 (defgroup elb nil
   "Emacs Lisp benchmarks."



[elpa] externals/org-modern ea829ce4b3: Fix progress bar, add more examples

2024-05-15 Thread ELPA Syncer
branch: externals/org-modern
commit ea829ce4b3ac035808d411b1a088e0947d75f554
Author: Daniel Mendler 
Commit: Daniel Mendler 

Fix progress bar, add more examples
---
 example.org   | 44 +++-
 org-modern.el | 15 ---
 2 files changed, 39 insertions(+), 20 deletions(-)

diff --git a/example.org b/example.org
index effdb462bf..177cde8a27 100644
--- a/example.org
+++ b/example.org
@@ -120,16 +120,34 @@ radio link
 
 * Progress bars
 
-- progress [1/13]
-- progress [2/13]
-- progress [3/13]
-- progress [4/13]
-- progress [5/13]
-- progress [6/13]
-- progress [7/13]
-- progress [8/13]
-- progress [9/13]
-- progress [10/13]
-- progress [11/13]
-- progress [12/13]
-- progress [13/13]
+- quotient [1/13]
+- quotient [2/13]
+- quotient [3/13]
+- quotient [4/13]
+- quotient [5/13]
+- quotient [6/13]
+- quotient [7/13]
+- quotient [8/13]
+- quotient [9/13]
+- quotient [10/13]
+- quotient [11/13]
+- quotient [12/13]
+- quotient [13/13]
+
+- percent [0%]
+- percent [1%]
+- percent [2%]
+- percent [5%]
+- percent [10%]
+- percent [20%]
+- percent [30%]
+- percent [40%]
+- percent [50%]
+- percent [60%]
+- percent [70%]
+- percent [80%]
+- percent [90%]
+- percent [100%]
+
+- overflow [110%]
+- overflow [20/10]
diff --git a/org-modern.el b/org-modern.el
index cd8c11daaa..a9bd4c0276 100644
--- a/org-modern.el
+++ b/org-modern.el
@@ -418,12 +418,13 @@ the font.")
   "Prettify progress as color-coded bar."
   (let* ((beg (match-beginning 1))
  (end (match-end 1))
- (val (if (match-beginning 2)
-  (* 0.01 (string-to-number (match-string-no-properties 2)))
-(let ((q (string-to-number (match-string-no-properties 4
-  (if (= q 0)
-  1.0
-(/ (* 1.0 (string-to-number (match-string-no-properties 
3))) q)
+ (val (min 1.0
+   (if (match-beginning 2)
+   (* 0.01 (string-to-number (match-string-no-properties 
2)))
+ (let ((q (string-to-number (match-string-no-properties 
4
+   (if (= q 0)
+   1.0
+ (/ (* 1.0 (string-to-number 
(match-string-no-properties 3))) q))
  (w org-modern-progress)
  (complete (floor (* w val)))
  (w0 (- end beg 2))
@@ -435,7 +436,7 @@ the font.")
 (put-text-property complete w 'face 'org-modern-progress-incomplete bar)
 (put-text-property beg end 'face 'org-modern-label)
 (put-text-property beg (1+ beg) 'display (substring bar 0 w1))
-(put-text-property (1- end) end 'display (substring bar (- w w1) w))
+(put-text-property (1- end) end 'display (substring bar (+ w1 w0) w))
 (dotimes (i w0)
   (put-text-property (+ 1 beg i) (+ 2 beg i)
  'display (substring bar (+ w1 i) (+ w1 i 1))



[nongnu] elpa/slime 77fb499e58: Erase *log-output* in clisp on startup.

2024-05-15 Thread ELPA Syncer
branch: elpa/slime
commit 77fb499e5803bfe162f2299ec767bb15466de0a8
Author: Stas Boukarev 
Commit: Stas Boukarev 

Erase *log-output* in clisp on startup.

Sadly, it doesn't have a hook that runs before saveinitmem.
---
 swank/clisp.lisp | 6 ++
 1 file changed, 6 insertions(+)

diff --git a/swank/clisp.lisp b/swank/clisp.lisp
index d028c9ed96..f53b40eb6d 100644
--- a/swank/clisp.lisp
+++ b/swank/clisp.lisp
@@ -934,3 +934,9 @@ Execute BODY with NAME's function slot set to FUNCTION."
 ,@(if restart-function 
   `((:init-function ,restart-function))
 (apply #'ext:saveinitmem args)))
+
+(pushnew (lambda ()
+   (when *log-output*
+ (setf *log-output* nil))
+   (swank::init-log-output))
+ custom:*init-hooks*)



[elpa] externals/bufferlo b0666495cc: Streamline getting the local list and killing local buffers

2024-05-15 Thread ELPA Syncer
branch: externals/bufferlo
commit b0666495cc391290d61f79eacdc32dca8fafabe0
Author: Florian Rommel 
Commit: Florian Rommel 

Streamline getting the local list and killing local buffers

Encapsulates getting the local buffer list for an arbitrary tab or an
entire frame (all its tabs).
This also fixes `bufferlo-delete-frame-kill-buffers', which previously
only killed the buffers of the current tab.
Furthermore, it prevents the `bufferlo-*-kill' functions from deleting
internal buffers by default.
---
 bufferlo.el | 168 +++-
 1 file changed, 109 insertions(+), 59 deletions(-)

diff --git a/bufferlo.el b/bufferlo.el
index 960f4fef12..95ff0f32fd 100644
--- a/bufferlo.el
+++ b/bufferlo.el
@@ -352,19 +352,32 @@ Argument IGNORE is for compatibility with 
`tab-bar-tab-post-open-functions'."
(mapcar 'get-buffer
(car (cdr (assq 'bufferlo-buffer-list (assq 'ws tab)))
 
+(defun bufferlo--get-buffers (&optional frame tabnum)
+  "Get the buffers of tab TABNUM in FRAME.
+If FRAME is nil, the current frame is selected.
+If TABNUM is nil, the current tab is selected.
+If TABNUM is \\='all, all tabs of the frame are selected."
+  (cond ((eq tabnum 'all)
+ (seq-uniq (mapcan (lambda (tb)
+ (if (eq 'current-tab (car tb))
+ (bufferlo--current-buffers frame)
+   (bufferlo--get-tab-buffers tb)))
+   (funcall tab-bar-tabs-function frame
+(tabnum
+ (let ((tab (nth tabnum (funcall tab-bar-tabs-function frame
+   (if (eq 'current-tab (car tab))
+   (bufferlo--current-buffers frame)
+ (bufferlo--get-tab-buffers tab
+(t
+ (bufferlo--current-buffers frame
+
 (defun bufferlo-buffer-list (&optional frame tabnum include-hidden)
   "Return a list of all live buffers associated with the current frame and tab.
 A non-nil value of FRAME selects a specific frame instead of the current one.
 If TABNUM is nil, the current tab is used.  If it is non-nil, it specifies
 a tab index in the given frame.  If INCLUDE-HIDDEN is set, include hidden
 buffers, see `bufferlo-hidden-buffers'."
-  (let ((list
- (if tabnum
- (let ((tab (nth tabnum (frame-parameter frame 'tabs
-   (if (eq 'current-tab (car tab))
-   (bufferlo--current-buffers frame)
- (bufferlo--get-tab-buffers tab)))
-   (bufferlo--current-buffers frame
+  (let ((list (bufferlo--get-buffers frame tabnum)))
 (if include-hidden
 (seq-filter #'buffer-live-p list)
   (seq-filter (lambda (buffer)
@@ -475,7 +488,7 @@ If FRAME is nil, use the current frame."
   "Remove all buffers from the local buffer list that are not exclusive to it."
   (interactive)
   (bufferlo--warn)
-  (dolist (buffer (bufferlo--get-exclusive-buffers nil t))
+  (dolist (buffer (bufferlo--get-exclusive-buffers nil nil t))
 (bufferlo-remove buffer)))
 
 (defun bufferlo-bury (&optional buffer-or-name)
@@ -488,28 +501,43 @@ effect as a simple `bury-buffer'."
 (bury-buffer-internal buffer)
 (bufferlo-remove buffer)))
 
-(defun bufferlo--get-captured-buffers (&optional exclude-frame)
+(defun bufferlo--get-captured-buffers (&optional exclude-frame exclude-tabnum)
   "Get all buffers that are in a local list of at least one frame or tab.
-If EXCLUDE-FRAME is a frame, exclude the local buffer list of this frame."
-  (let* ((flatten (lambda (list)
+If EXCLUDE-FRAME is a frame, exclude the local buffer list of the tab with
+the number EXCLUSIVE-TABNUM of this frame.
+If EXCLUSIVE-TABNUM is nil, select the default tab.
+If EXCLUSIVE-TABNUM is \\='all, select all tabs of the frame.
+If EXCLUDE-FRAME is nil, do not exclude a local buffer list
+and ignore EXCLUDE-TABNUM."
+  (let* ((exclude-tab (when (and exclude-tabnum (not (eq exclude-tabnum 'all)))
+(nth exclude-tabnum
+ (funcall tab-bar-tabs-function exclude-frame
+ (flatten (lambda (list)
 (apply #'append (append list '(nil)
- (get-inactive-tabs-buffers (lambda (f)
-  (funcall flatten
-   (mapcar
-#'bufferlo--get-tab-buffers
-(frame-parameter f 'tabs)
- (get-frames-buffers (lambda ()
-   (funcall flatten
-(mapcar
- (lambda (f)
-   (unless (eq f exclude-frame)
- (bufferlo--current-buffers f)))
- (frame-list))
+ (get-inactive-tabs-buffers
+  (lambda (f)
+  

[nongnu] elpa/hyperdrive 36cc7612fd: Docs: Update release checklists

2024-05-15 Thread ELPA Syncer
branch: elpa/hyperdrive
commit 36cc7612fdecfb6ed7dfd542d8652f1fd4e496c8
Author: Adam Porter 
Commit: Adam Porter 

Docs: Update release checklists
---
 CONTRIBUTING.org | 43 ++-
 1 file changed, 34 insertions(+), 9 deletions(-)

diff --git a/CONTRIBUTING.org b/CONTRIBUTING.org
index d477ad1829..e4aa0317cf 100644
--- a/CONTRIBUTING.org
+++ b/CONTRIBUTING.org
@@ -25,25 +25,50 @@ As well, sometimes two keywords might be used together if 
the lines between them
 
 * Release checklist
 
-These steps should be followed when releasing a new version:
+These checklists should be followed when releasing new versions:
 
-1. Release new version.
+** Commit new pre-release
+:PROPERTIES:
+:ID:   5f7859bc-5f9b-4e35-806e-b727f492dade
+:END:
 
In ~master~ branch:
 
-   1. [ ] Update package main file header version (removing ~-pre~ suffix).
-   2. [ ] Update CHANGELOG (with release date and version).
-   3. [ ] Rebuild .texi manual.
+   1. [ ] Update package main file header version (adding ~-pre~ suffix).
+   2. [ ] Update CHANGELOG.
+   3. [ ] Rebuild .texi manual (use ~pre-commit~ hook; see below).
4. [ ] Commit changes.
 
-2. Commit new pre-release.
+** Release new feature (or minor) version
 
In ~master~ branch:
 
-   1. [ ] Update package main file header version (adding ~-pre~ suffix).
-   2. [ ] Update CHANGELOG.
-   3. [ ] Rebuild .texi manual.
+   1. [ ] Update package main file header version (removing ~-pre~ suffix).
+   2. [ ] Update CHANGELOG (with release date and version).
+   3. [ ] Rebuild .texi manual (use ~pre-commit~ hook; see below).
4. [ ] Commit changes.
+   5. [ ] Merge ~master~ branch into ~stable~ branch.
+   6. [ ] Make new git tag for new release (tagging the commit on ~stable~).
+   7. [ ] Push ~master~ and ~stable~ branches to remote.
+   8. [ ] Push git tags.
+   9. [ ] [[id:5f7859bc-5f9b-4e35-806e-b727f492dade][Commit new pre-release]] 
before adding more changes.
+
+** Release new bugfix version (when applying bug fixes to a stable release, 
not to ~master~)
+
+   In ~stable~ branch:
+
+   1. [ ] Update package main file header version (increment bugfix number 
(i.e. the third number), adding ~-pre~ suffix).
+   2. [ ] Commit fixes to code.
+   3. [ ] Commit update to ~CHANGELOG~.
+   4. [ ] Rebuild manual.
+   5. [ ] Commit manual.
+   6. [ ] Update package main file header version (removing ~-pre~ suffix).
+   7. [ ] Commit changes.
+   8. [ ] Make new git tag for new release.
+   9. [ ] Push ~stable~ branch to remote.
+   10. [ ] Merge ~stable~ branch back to ~master~.
+   11. [ ] Push ~master~ branch to remote.
+   12. [ ] Push git tags.
 
 * Git hooks
 



[nongnu] elpa/reformatter 6b49d5b66d 1/2: chore(deps): bump cachix/install-nix-action from 26 to 27

2024-05-15 Thread ELPA Syncer
branch: elpa/reformatter
commit 6b49d5b66d105c0eb02c84417b3ad1fcafc57a37
Author: dependabot[bot] <49699333+dependabot[bot]@users.noreply.github.com>
Commit: GitHub 

chore(deps): bump cachix/install-nix-action from 26 to 27

Bumps 
[cachix/install-nix-action](https://github.com/cachix/install-nix-action) from 
26 to 27.
- [Release notes](https://github.com/cachix/install-nix-action/releases)
- [Commits](https://github.com/cachix/install-nix-action/compare/v26...V27)

---
updated-dependencies:
- dependency-name: cachix/install-nix-action
  dependency-type: direct:production
  update-type: version-update:semver-major
...

Signed-off-by: dependabot[bot] 
---
 .github/workflows/test.yml | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/.github/workflows/test.yml b/.github/workflows/test.yml
index ce25a3cdd0..e5c222a845 100644
--- a/.github/workflows/test.yml
+++ b/.github/workflows/test.yml
@@ -35,7 +35,7 @@ jobs:
   - 29.1
   - snapshot
 steps:
-- uses: cachix/install-nix-action@v26
+- uses: cachix/install-nix-action@V27
   with:
 nix_path: nixpkgs=channel:nixos-unstable
 - uses: purcell/setup-emacs@master



[nongnu] elpa/reformatter 0d29a04d69 2/2: Merge pull request #51 from purcell/dependabot/github_actions/cachix/install-nix-action-27

2024-05-15 Thread ELPA Syncer
branch: elpa/reformatter
commit 0d29a04d69d47599e2cb7f1a8f8e897a2b592921
Merge: a0d4ce7219 6b49d5b66d
Author: Steve Purcell 
Commit: GitHub 

Merge pull request #51 from 
purcell/dependabot/github_actions/cachix/install-nix-action-27

chore(deps): bump cachix/install-nix-action from 26 to 27
---
 .github/workflows/test.yml | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/.github/workflows/test.yml b/.github/workflows/test.yml
index ce25a3cdd0..e5c222a845 100644
--- a/.github/workflows/test.yml
+++ b/.github/workflows/test.yml
@@ -35,7 +35,7 @@ jobs:
   - 29.1
   - snapshot
 steps:
-- uses: cachix/install-nix-action@v26
+- uses: cachix/install-nix-action@V27
   with:
 nix_path: nixpkgs=channel:nixos-unstable
 - uses: purcell/setup-emacs@master
diff --git a/lisp/ox-taskjuggler.el b/lisp/ox-taskjuggler.el
index 4144685e1a..19e4da9d01 100644
--- a/lisp/ox-taskjuggler.el
+++ b/lisp/ox-taskjuggler.el
@@ -177,6 +177,13 @@ for the project."
   :group 'org-export-taskjuggler
   :type 'string)
 
+(defcustom org-taskjuggler-account-tag "taskjuggler_account"
+  "Tag marking project's accounts.
+This tag is used to find the tree containing all the accounts
+for the project."
+  :group 'org-export-taskjuggler
+  :type 'string)
+
 (defcustom org-taskjuggler-report-tag "taskjuggler_report"
   "Tag marking project's reports.
 This tag is used to find the tree containing all the reports for
@@ -330,16 +337,23 @@ list."
 
 (defcustom org-taskjuggler-valid-resource-attributes
   '(limits vacation shift booking efficiency journalentry rate
-  workinghours flags)
+  workinghours flags chargeset)
   "Valid attributes for Taskjuggler resources.
 If one of these appears as a property for a headline, it will be
 exported with the corresponding resource."
   :group 'org-export-taskjuggler
   :type '(repeat symbol))
 
+(defcustom org-taskjuggler-valid-account-attributes
+  '(aggregate credits flags)
+  "Valid attributes for Taskjuggler accounts.
+If one of these appears as a property for a headline, it will be
+exported with the corresponding account."
+  :group 'org-export-taskjuggler)
+
 (defcustom org-taskjuggler-valid-report-attributes
-  '(headline columns definitions timeformat hideresource hidetask
-loadunit sorttasks formats period)
+  '(headline columns definitions timeformat hideaccount hideresource hidetask
+loadunit sorttasks formats period start end)
   "Valid attributes for Taskjuggler reports.
 If one of these appears as a property for a headline, it will be
 exported with the corresponding report."
@@ -446,6 +460,19 @@ headlines and their associated ID."
   (cons resource id)))
   info)))
 
+(defun org-taskjuggler-assign-account-ids (accounts info)
+  "Assign a unique ID to each account within ACCOUNTS.
+ACCOUNTS is a list of headlines.  INFO is a plist used as a
+communication channel.  Return value is an alist between
+headlines and their associated ID."
+  (let (ids)
+(org-element-map accounts 'headline
+  (lambda (account)
+(let ((id (org-taskjuggler--build-unique-id account ids)))
+  (push id ids)
+  (cons account id)))
+  info)))
+
 
 
 ;;; Accessors
@@ -497,11 +524,10 @@ doesn't have any start date defined."
 ITEM is a headline.  Return value is a string or nil if ITEM
 doesn't have any end date defined."
   (let ((deadline (org-element-property :deadline item)))
-(and deadline (funcall (eval-and-compile
-(if (fboundp 'org-format-timestamp)
-#'org-format-timestamp
-  (with-no-warnings #'org-timestamp-format)))
-  deadline "%Y-%02m-%02d"
+(or
+ (and deadline (org-timestamp-format deadline "%Y-%02m-%02d"))
+ (and (memq 'end org-taskjuggler-valid-task-attributes)
+ (org-element-property :END item)
 
 
 
@@ -654,89 +680,115 @@ Return complete project plan as a string in TaskJuggler 
syntax."
  (org-taskjuggler--build-project project info)
  ;; 3. Insert global properties.
  (org-element-normalize-string org-taskjuggler-default-global-properties)
  ;; 4. Insert resources.  Provide a default one if none is
  ;;specified.
- (let ((main-resources
+ (let ((main-accounts
 ;; Collect contents from various trees marked with
 ;; `org-taskjuggler-resource-tag'.  Only gather top level
 ;; resources.
 (apply 'append
(org-element-map tree 'headline
  (lambda (hl)
-   (and (member org-taskjuggler-resource-tag
+   (and (member org-taskjuggler-ac

[elpa] externals/elisp-benchmarks updated (f0f0ce9a94 -> 869a51d702)

2024-05-15 Thread Andrea Corallo
akrl pushed a change to branch externals/elisp-benchmarks.

  from  f0f0ce9a94 ; * elisp-benchmarks.el: Update copyright year
   new  fccb7bbaad * Handle 'compilation-safety'
   new  869a51d702 * elisp-benchmarks.el: Bump new version.


Summary of changes:
 elisp-benchmarks.el | 10 +-
 1 file changed, 9 insertions(+), 1 deletion(-)



[elpa] externals/elisp-benchmarks 869a51d702 2/2: * elisp-benchmarks.el: Bump new version.

2024-05-15 Thread Andrea Corallo
branch: externals/elisp-benchmarks
commit 869a51d70200b2e86e0b78793f4a99c8e690b996
Author: Andrea Corallo 
Commit: Andrea Corallo 

* elisp-benchmarks.el: Bump new version.
---
 elisp-benchmarks.el | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)
@@ -654,89 +680,115 @@ Return complete project plan as a string in TaskJuggler 
  ;; 3. Insert global properties.
  (org-element-normalize-string org-taskjuggler-default-global-properties)
- ;; 4. Insert resources.  Provide a default one if none is
+ ;; 3.5. Insert accounts.  Provide a default one if none is
  ;;specified.
@@ -654,89 +680,115 @@ Return complete project plan as a string in TaskJuggler 
 ;; Collect contents from various trees marked with
-;; `org-taskjuggler-resource-tag'.  Only gather top level
-;; resources.
+;; `org-taskjuggler-account-tag'.  Only gather top level
+;; accounts.
 (apply 'append
(org-element-map tree 'headline
